@@ -1,6 +1,3 @@
-#ifndef breezedetectwidget_h
-#define breezedetectwidget_h
-
 //////////////////////////////////////////////////////////////////////////////
 // breezedetectwidget.h
 // Note: this class is a stripped down version of
@@ -14,6 +11,8 @@
 // SPDX-License-Identifier: MIT
 //////////////////////////////////////////////////////////////////////////////
 
+#pragma once
+
 #include <QObject>
 #include <QVariantMap>
 
@@ -42,5 +41,3 @@ private:
 };
 
 } // namespace
-
-#endif
