@@ -1,5 +1,3 @@
-#ifndef breezeexceptionmodel_h
-#define breezeexceptionmodel_h
 //////////////////////////////////////////////////////////////////////////////
 // breezeexceptionmodel.h
 // -------------------
@@ -9,6 +7,8 @@
 // SPDX-License-Identifier: MIT
 //////////////////////////////////////////////////////////////////////////////
 
+#pragma once
+
 #include "breeze.h"
 #include "breezelistmodel.h"
 #include "breezesettings.h"
@@ -58,4 +58,3 @@ private:
 };
 
 }
-#endif
